@@ -34,8 +34,10 @@ function qualityplot(data, i) {
     var barplot = d3.select("#qualityplot_" + i)
 	.append("svg")
 	.attr("class", "chart")
-	.attr("width", w + p )
-	.attr("height", h + p );
+	.attr("width", "100%" )
+	.attr("height", h + p )
+        .attr("viewBox", "0 0 "+(w+p)+" "+(h+p));
+        //.attr("preserveAspectRatio", "xMidyMid");
 
     // x-axis
     barplot.selectAll("g.x.axis")
