@@ -173,7 +173,7 @@ def read_fastab(stream, maxhead = 500, maxseq = 100000):
         if nhead > maxhead:
             raise FastabError("Header size over the limit (%i > %i)" % (nhead, maxhead))
         if nseq > maxseq:
-            raise FastabError("Sequence size over the limit (%i > %i)" % (nhead, maxhead))
+            raise FastabError("Sequence size over the limit (%i > %i)" % (nseq, maxseq))
 
         raw = stream.read(nhead)
         
