@@ -32,12 +32,13 @@ from ngs_plumbing._libxsq import colourqual_frombuffer, basequal_frombuffer, byt
 ColourQual = namedtuple('ColourQual', 'colour qual')
 
 _ACGT = bytes('ACGT')
-FRAGMENT_NAMES = ('F3', 'F5-DNA', 'R3', 'R5')
+FRAGMENT_NAMES = ('F3', 'F5-DNA', 'F5-RNA', 'R3', 'R5')
 # F3: Forward strand. starts with a T
 # F5/R3: Used to prime both F5-BC read and R3 or barcode. starts with a G
 #
 FRAGMENT_START = {'F3': b'T',
                   'F5-DNA': b'G',
+                  'F5-RNA': b'G', # to be verified
                   'R3': b'G',
                   'R5': None # I don' know
 }
