@@ -162,7 +162,18 @@ def htmlreport():
             sys.exit(1)
     else:
         if option.force:
-            os.mkdir(options.dest_dir)
+            sys.stdout.write('Creating directory missing...')
+            sys.stdout.flush()
+            try:
+                os.mkdir(options.dest_dir)
+            except OSError, ose:
+                sys.stderr.write('\n')
+                sys.stderr.write(str(ose))
+                sys.stderr.write('\n')
+                sys.stderr.flush()
+                sys.exit(1)
+            sys.stdout.write('done.\n')
+            sys.stdout.flush()
         else:
             print('Error: destination directory does not exist.')
             sys.exit(1)
@@ -175,8 +186,9 @@ def htmlreport():
     dest_dir = os.path.join(options.dest_dir, xsq_fn[:sep_i])
     try:
         os.mkdir(dest_dir)
-    except:
-        sys.stderr.write('Could not create directory %s\n' % dest_dir)
+    except OSError, ose:
+        sys.stderr.write(str(ose))
+        sys.stderr.write('\n')
         sys.stderr.flush()
         sys.exit(1)
     if os.path.exists(options.dest_dir):
